@@ -2,7 +2,7 @@ package Search::Kinosearch;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.021';
 
 ### Coding convention:
 ### Public methods use hash style parameters except when to do so would cause 
@@ -130,12 +130,18 @@ Search::Kinosearch - Search Engine Library
 
 =head1 WARNING
 
-Search::Kinosearch is ALPHA test software.  Aspects of the interface are
-almost certain to change, given the suite's complexity.  Users should not
-count on compatibility of files created by Kinosearch when future versions are
-released -- any time you upgrade Kinosearch (or possibly, a module such as
-L<Lingua::Stem::Snowball|Lingua::Stem::Snowball> on which Kinosearch depends),
-you should expect to regenerate all kindex files from scratch. 
+Search::Kinosearch is ALPHA test software.  A MAJOR CHANGE TO THE API which
+will BREAK BACKWARDS COMPATIBILITY is scheduled. 
+
+Bug fix releases will continue for the current stable 0.02 branch until the
+new branch is ready.  If you wish to use Kinosearch for production, you should
+use the 0.02 branch and make sure that you are in a position to control when
+the installed version of Kinosearch gets upgraded.  
+
+For a basic idea of what is planned, see the TODO list below.  If you would
+to help shape the new version, consider subscribing to the Kinosearch mailing
+list, which can be found via the Kinosearch homepage:
+L<http://www.rectangular.com/kinosearch>.
 
 =head1 SYNOPSIS
 
@@ -145,7 +151,8 @@ First, write an application to build a 'kindex' from your document collection.
     use Search::Kinosearch::Kindexer;
     
     my $kindexer = Search::Kinosearch::Kindexer->new(
-        -mainpath => '/foo/bar/kindex',
+        -mainpath       => '/foo/bar/kindex',
+        -temp_directory => '/foo/bar',
         );
     
     for my $field ('title', 'bodytext') {
@@ -491,30 +498,30 @@ documentation for Kindexer's define_field() method for more details.
 
 =end comment
 
-
 =head1 TO DO
 
 =over
 
 =item
 
-Implement data compression methods.
+Overhaul the API.  Kinosearch's major classes have grown too large, and need to
+be reimplemented as extensible abstract base classes.  
+
+For instance, the current version of Search::Kinosearch::Kindex is limited
+because it specifies particular file configurations and tie classes.  It is
+being reworked as a a Perl complex data structure which represents only the
+abstract format of a kindex.  Happily, the new version will work fine as an
+in-memory kindex on its own, speeding testing and development.  Subclasses,
+such as the Search::Kinosearch::Kindex::FS, will be implemented primarily
+through the use of Perl's TIE mechanism.
 
 =item
 
-Refine the API.
+Dispense with DB_File altogether and implement a composite index format.
 
 =item
 
-Dispense with DB_File and implement a composite index format.
-
-=item
-
-Shrink proximity data.
-
-=item
-
-Enable range queries.
+Shrink proximity data.  Right now it's solid packed 32 bit integers.
 
 =item
 
@@ -527,7 +534,8 @@ Implement docrank.
 =item
 
 Fix excerpt highlighting for phrases so that a search for 'we the people'
-doesn't cause every instance of 'the' to be highlighted.
+doesn't cause every instance of 'the' to be highlighted. -- DONE in
+development version.
 
 =item
 
@@ -546,7 +554,9 @@ Add support for other encodings.
 =item
 
 Implement -cache_level option for Search::Kinosearch::Kindexer, in order to
-allow user control over memory requirements.
+allow user control over memory requirements.  This feature is dependent on the
+implementation of -mem_threshold in L<Sort::External|Sort::External>,
+being tested as of this writing.
 
 =item 
 
@@ -554,10 +564,6 @@ Implement descending term weighting.
 
 =item
 
-Implement alternative backends.
-
-=item 
-
 Add support for 64-bit timestamps.
 
 =item
@@ -580,7 +586,8 @@ Excerpt may be up to 20 characters longer than requested.
 
 Spurious results can turn up in searches for phrases 3
 terms or longer: for instance, a document containing "I<brush your> hair and
-floss I<your teeth>" will be returned in a search for '"brush your teeth"'.
+floss I<your teeth>" will be returned in a search for '"brush your teeth"'. --
+FIXED in development version.
 
 =back
 
