@@ -159,7 +159,7 @@ sub process {
     my $storable_fields = $self->{kindex}{fields_store};
     my $num_storable_fields = @$storable_fields;
     while (my $hit = shift @out) {
-        last if $valid_hits >= $last;
+        last if $valid_hits > $last;
         my ($score_or_string, $knum, $doc_num)
                 = unpack ($pack_template, $hit);
         next if exists 
@@ -216,7 +216,7 @@ sub process {
             { fields => \%stored_fields } );
         push @ranked_results, $doc;
         if ($self->{-sort_by} eq 'score') {    
-            $ranked_results[-1]{score} = $score_or_string/32_000;
+            $doc->{fields}{score} = $score_or_string/32_000;
         }
         if ($self->{-excerpt_field}) {
             $doc->set_field( 
