@@ -17,21 +17,13 @@ use Storable qw( nfreeze thaw nstore );
 
 my $tempdir_template = "kinotemp_XXXX";
 
-### Line separator, used by Sort::External for delimiting arbitrary 
-### binary data.
-my @randstringchars = (('A' .. 'Z'),('a' .. 'z'),(0 .. 9));
-my $line_separator;
-$line_separator .= $randstringchars[rand @randstringchars] for (1 .. 16);
-$line_separator = " __$line_separator\n";
-my $line_sep_reg = qr/$line_separator$/;
-
 ### Build the default path for the kindex output directory.
 my $current_directory = File::Spec->curdir();
 my $default_mainpath   = File::Spec->catdir( $current_directory, 'kindex' );
 $default_mainpath = File::Spec->rel2abs($default_mainpath);
 
 ### Don't distinguish developer versions.
-my ($kinosearch_version) = $Search::Kinosearch::VERSION =~ /([^_]+)_?/;
+my ($kinosearch_version) = ($Search::Kinosearch::VERSION =~ /(\d+\.\d\d)/);
 
 ##############################################################################
 ### Constructor
@@ -275,7 +267,7 @@ sub init_kindexer {
     $self->{kinodata_cache} = Sort::External->new(
         -working_dir => $self->{temp_dir},
         #-cache_size  => ??? TODO
-        -line_separator => $line_separator,
+        -line_separator => 'random',
         );
 }
 
@@ -572,8 +564,7 @@ sub _score_terms {
             = int(($aggscores{$term} / $norm_divisor) * 32_000);
             
         my $kinodata_entry = $term . "\0" . $sortstring . $datetime_string .
-            pack($kdt_pre_template, $doc_num, $normalized_aggscore, @fscores)
-            . $line_separator;
+            pack($kdt_pre_template, $doc_num, $normalized_aggscore, @fscores);
 
         ### For now, we store the precursors in memory.  
         push @entries, $kinodata_entry;
@@ -698,7 +689,6 @@ sub _consolidate_subkindex {
             }
             $_ .= shift @unpacked for @buffer;
         }
-        $_ .= $line_separator for @buffer;
         $buffer[$_] = '' for @invalid;
         $self->{kinodata_cache}->feed(@buffer);
     }
@@ -766,7 +756,8 @@ sub generate {
     my $started = 0;
     my $heldover_line;
 
-    while (my $line = $kinodata_cache->fetch) {
+    while (defined (my $line = $kinodata_cache->fetch)) {
+        next unless length $line;
         ++$loopcount;
         OPEN_KDATA: { # single iteration loop structure. 
             last unless $record_offset % $entries_per_kdata_file == 0;
@@ -795,8 +786,6 @@ sub generate {
         $line =~ s/^([^\0]*)\0// 
             or confess "Internal error. kinopre line content: $_";
         my $term = $1;
-        $line =~ s/$line_sep_reg//
-            or confess "Internal error. kinopre line content: $_";
         my @kdata_values
             = unpack($kdt_splitter_template, $line);
         
@@ -988,17 +977,16 @@ Search::Kinosearch::Kindexer - create kindex files
 
 =head1 WARNING
 
-Search::Kinosearch is ALPHA test software.  Aspects of the interface are
-almost certain to change, given the suite's complexity.  Users should not
-count on compatibility of files created by Kinosearch when future versions are
-released -- any time you upgrade Kinosearch (or possibly, a module such as
-L<Lingua::Stem::Snowball|Lingua::Stem::Snowball> on which Kinosearch depends),
-you should expect to regenerate all kindex files from scratch. 
+Kinosearch is ALPHA test software. 
+
+Please read the full warning in the L<Search::Kinosearch|Search::Kinosearch>
+documentation.
 
 =head1 SYNOPSIS
 
     my $kindexer = Search::Kinosearch::Kindexer->new(
-        -mainpath => '/foo/bar/kindex',
+        -mainpath       => '/foo/bar/kindex',
+        -temp_directory => '/foo/bar',
         );
     
     for my $field ('title', 'bodytext') {
@@ -1031,8 +1019,9 @@ How to create a kindex, in 7 easy steps...
 Step 1: Create a Kindexer object.
 
     my $kindexer = Search::Kinosearch::Kindexer->new(
-        -mainpath => '/foo/bar/kindex',
-        -mode => 'overwrite',
+        -mainpath       => '/foo/bar/kindex',
+        -temp_directory => '/foo/bar',
+        -mode           => 'overwrite',
         );
 
 Step 2: Define all the fields that you'll ever need this kindex to have --
@@ -1097,9 +1086,10 @@ in how you treat the Kindexer, though you may wish to choose a custom setting fo
 -optimization.
 
     my $kindexer = Search::Kinosearch::Kindexer->new(
-        -mainpath     => '/path/to/kindex',
-        -mode         => 'update',
-        -optimization => 1,
+        -mainpath       => '/path/to/kindex',
+        -temp_directory => '/foo/bar',
+        -mode           => 'update',
+        -optimization   => 1,
         );
 
 If you want to overwrite a document currently in the kindex, simply call
@@ -1175,7 +1165,8 @@ don't specify -freqpath, it appears as a directory called 'freqdata' within
 
 The Kindexer object will create a single randomly-named temp directory within
 whatever is specified as -temp_directory, then use that inner directory for
-all its temporary files.
+all its temporary files. B<BUG:> In the 0.02 branch of Kinosearch, the
+-temp_directory MUST be on the same filesystem as the kindex itself. 
 
 =item -optimization
 
@@ -1378,6 +1369,11 @@ Private.
 
 =end comment
 
+=head1 BUGS
+
+The -temp_directory must be on the same filesystem as -mainpath, or the move()
+operation may fail.
+
 =head1 TO DO
 
 =over
